#!/bin/ksh
# Licensed Materials - Property of IBM
# Restricted Materials of IBM
#
# Copyright IBM Corp. 2009 All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
# Release Name: omoracle_FP1A
#
#  Description: Copy the patch xml file into the depot
#               so that the remote deploy GUI panel is updated.
#
#  Parameters:
#    CANDLEHOME, set in the environment
#
#  Returns:
#    None
#============================================================
#set -x

PATCHID=6.1.0.1-TIV-ITM_ORA-IF0014
XML_SRC=or_dd_061001014.xml
XML_DST=or_dd_061001000.xml
OR_PROP=or_dd.properties

# ask for the ITM 6.1 install directory if not in the environment
if [ ! -d $CANDLEHOME/tmaitm6 ]; then
  while true
  do
    echo "Enter the path of the IBM Tivoli Monitoring directory or q to quit:"
    read CANDLEHOME
    if [ "${CANDLEHOME}" = "q"  ]; then
      echo "kor_patchdepot.sh exiting..."
      exit 100
    fi
    if [ -d $CANDLEHOME/tmaitm6 ]; then
      export CANDLEHOME
      break
    else
      echo "ERROR: $CANDLEHOME/tmaitm6 was not found..."
    fi
  done
fi

# Make sure the source files are in the current running directory
if [[ ! -f $XML_SRC || ! -f $OR_PROP ]]; then
  echo "$XML_SRC or $OR_PROP was not found..."
  echo "You must run kor_patchdepot.sh from the extracted $PATCHID directory..."
  echo "kor_patchdepot.sh exiting..."
  exit 100
fi
cwd=`pwd`

echo "Are you sure you want to patch the depot for $PATCHID, enter (y/n):"
read ANS
if [ "$ANS" != "y"  ]; then
  echo "kor_patchdepot.sh exiting..."
  exit 100
fi

# cd to the destination directory and do the copies
cd $CANDLEHOME/tables
FILES=`find . -name $XML_DST -type f -print`
for file in $FILES
do
  echo "Modifying $CANDLEHOME/tables/$HOSTNAME/depot/PACKAGES/$file"
  cp $cwd/$XML_SRC $file
  echo "Modifying $CANDLEHOME/tables/$HOSTNAME/depot/PACKAGES/${file%/*}/$OR_PROP"
  cp $cwd/$OR_PROP ${file%/*}/$OR_PROP
done

echo "kor_patchdepot.sh completed..."

exit 0
